@@ -5,25 +5,16 @@ use overload
   '""'     => sub { shift->to_string },
   fallback => 1;
 
-has 'dbi',
-    orders => sub { [] };
+has orders => sub { [] };
 
-sub prepend {
-    my $self = shift;
-    
-    for my $order (reverse @_) {
-        unshift @{$self->orders}, $order;
-    }
-    
-    return $self;
-}
+sub prepend { unshift @{shift->orders}, @_ }
 
 sub to_string {
     my $self = shift;
     
     my $exists = {};
     my @orders;
-    for my $order (@{$self->orders}) {
+    foreach my $order (@{$self->orders}) {
         next unless defined $order;
         $order =~ s/^\s+//;
         $order =~ s/\s+$//;
@@ -40,7 +31,7 @@ sub to_string {
 
 =head1 NAME
 
-DBIx::Custom::Order - Order by
+DBIx::Custom::Order - Order by EXPERIMENTAL
 
 =head1 SYNOPSIS
 
@@ -49,15 +40,9 @@ DBIx::Custom::Order - Order by
     $order->prepend('title', 'author desc');
     my $order_by = "$order";
     
+
 =head1 ATTRIBUTES
 
-=head2 C<dbi>
-
-    my $dbi = $order->dbi;
-    $order = $order->dbi($dbi);
-
-L<DBIx::Custom> object.
-
 =head2 C<orders>
 
     my $orders = $result->orders;
